OiRA

Help

1. Příprava
2. Zapojení
3. Vyhledání rizik + Hodnocení rizik
4. Akční plán
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Pozornost
5. Zpráva
6. Status 9%

# Commercial guarding, Leicester

Navrhněte opatření k odstranění nebo omezení rizik. Vyberte standardní opatření nebo navrhněte vlastní. Preferujte technická a organizační opatření před používáním osobních ochranných pracovních prostředků (dále jen „OOPP“).

U jednotlivých rizik zvažte:

1. jestli je možné se riziku vyhnout tj:
   - zda je opravdu nutné provádět pracovní činnost, která je zdrojem rizika,
   - zda nelze zdroj rizika nějakým způsobem odstranit nebo nahradit,
2. jak snížit úroveň rizika na co nejnižší míru v případě, že jej nelze odstranit

Jakmile se rozhodnete, jakým způsobem riziko odstranit nebo snížit, popište jednotlivé kroky potřebné k realizaci. Popište opatření, stanovte odpovědnou osobu, míru potřebných znalostí, lhůtu k provedení opatření a rozpočet.

Vytvořit akční plán

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More